# Shapley values

An open-source library of [Shapley value algorithms](https://en.wikipedia.org/wiki/Shapley_value) in Python.

***For example of "Shapley values" algorithm you can enter to: [example of "Shapley values"](http://liadn7.pythonanywhere.com/)***

## Installation

    clone https://github.com/LIADN7/shapley_values.git
    cd shapley_values
    pip install -r requirements.txt
    pip install -e .

To verify that everything was installed correctly, run one of the test programs,

    python shapley_values/tests/test_shap.py
    python shapley_values/tests/test_x_shapley.py


## Other algorithms implemented:
  ***[X_Shapley](https://www.aaai.org/AAAI22Papers/SA-00194-NizriM.pdf)***




